@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # encoding: utf-8
 """
-texture.py
+test_texture.py
 
 Created by Damian Cugley on 2011-01-12.
-Copyright (c) 2011 Damian Cugley. All rights reserved.
+Copyright © 2011 Damian Cugley. All rights reserved.
 """
 
 import sys
@@ -13,6 +13,7 @@ import unittest
 from mock import Mock, patch
 
 from texturepacker import *
+
 from datetime import datetime, timedelta
 from zipfile import ZipFile, ZipInfo, ZIP_DEFLATED
 from StringIO import StringIO
@@ -786,7 +787,6 @@ class MixerTests(TestCase):
             ]
         }, {'a.png': 'a_b_replace.png'}, ['b.png'])
 
-
     def test_a_b_replace_single_mix(self):
         # The difference here is that the mix can be 1 dict instead of a lst
         self.check_recipe({
@@ -1262,6 +1262,28 @@ class MixerTests(TestCase):
         self.assertEqual('AB', pack.label)
         self.assertEqual('Has A! Has B!!', pack.desc)
 
+    def test_blank_source(self):
+        # The difference here is that the mix can be 1 dict instead of a lst
+        self.check_recipe({
+            'mix': {
+                'pack': '$alpha_bravo',
+                'files': [
+                    {
+                        'file': 'a.png',
+                        'source':  {
+                            'background': 'transparent',
+                            'width': 64,
+                            'height': 64,
+                        },
+                        'replace': {
+                            'source': 'a.png',
+                            'cells':  ['a', 'b', 'c', 'd']
+                        }
+                    }
+                ]
+            }
+        }, {'a.png': 'a_64x64.png'}, ['b.png'])
+
     def check_recipe(self, recipe, expected_resources, unexpected_resources):
         recipe.update({
             'label': 'Composite pack',
